==> qxmpp_0.7.3.orig.tar.gz: qxmpp-0.7.3/doc/html/search/all_72.js <==
var searchData=
[
  ['readframes',['readFrames',['../classQXmppRtpVideoChannel.html#a2d2c5854406f34fedbd10d6096428493',1,'QXmppRtpVideoChannel']]],
  ['reason',['reason',['../classQXmppJingleIq.html#a0109cfd1525f9ee69a40ae0ce3962d69',1,'QXmppJingleIq::reason()'],['../classQXmppJingleIq.html#a9027b28bc5f929ee415f0de50563cac7',1,'QXmppJingleIq::reason() const '],['../classQXmppMucItem.html#a7b5574030b7bb253c23ccf46fffde87e',1,'QXmppMucItem::reason()']]],
  ['receiptid',['receiptId',['../classQXmppMessage.html#a3df33f75c06de9a3fbe3897ca89893db',1,'QXmppMessage']]],
  ['receivedmessage',['ReceivedMessage',['../classQXmppLogger.html#a932dbbd4f70a1e9c0ff8f452e61fc9b8a9fe070da70e5b2a5c2e6e97a58ee8da7',1,'QXmppLogger']]],
  ['refusesubscription',['refuseSubscription',['../classQXmppRosterManager.html#a9e9ffd157b981d1fb4a3b641de2890c7',1,'QXmppRosterManager']]],
  ['region',['region',['../classQXmppVCardAddress.html#a02bd9c333ef0d1d3eac3853bb8391849',1,'QXmppVCardAddress']]],
  ['relayedtype',['RelayedType',['../classQXmppJingleCandidate.html#a6314b3ed7de59b68131db6ffab55fe7daca50a30f0ac47c89e25b5f74b846cffb',1,'QXmppJingleCandidate']]],
  ['remotedomain',['remoteDomain',['../classQXmppOutgoingServer.html#acf167e9cf078b1ee9ef80fd2d3ac0b83',1,'QXmppOutgoingServer']]],
  ['remove',['Remove',['../classQXmppRosterIq_1_1Item.html#a0133cf9262cec7e299c4db7c247c5514a126d552db04eb0336747ca34e2c91cee',1,'QXmppRosterIq::Item']]],
  ['removecollections',['removeCollections',['../classQXmppArchiveManager.html#a3de27735449b3fb10a1e85032ed3e0b6',1,'QXmppArchiveManager']]],
  ['removeextension',['removeExtension',['../classQXmppClient.html#ae48477dc92abd66193789bfc60d16d62',1,'QXmppClient']]],
  ['removeitem',['removeItem',['../classQXmppRosterManager.html#a0ac3bd1ee2cbe8e99c3da55f9423fe20',1,'QXmppRosterManager']]],
  ['renameitem',['renameItem',['../classQXmppRosterManager.html#a65ecf5954b56e1d38be5b3554c4e3f30',1,'QXmppRosterManager']]],
  ['reopen',['reopen',['../classQXmppLogger.html#a18ebf48f34358d20dd57502a9db2f0c0',1,'QXmppLogger']]],
  ['requestclientvcard',['requestClientVCard',['../classQXmppVCardManager.html#a3f049d6356f93f5f8fa81a1c30ea5ba9',1,'QXmppVCardManager']]],
  ['requestconfiguration',['requestConfiguration',['../classQXmppMucRoom.html#ab20d3d15a70354d109d1f30a13c8c1df',1,'QXmppMucRoom']]],
  ['requestinfo',['requestInfo',['../classQXmppDiscoveryManager.html#a81facc7b29132ee7f13c26d8d441e611',1,'QXmppDiscoveryManager']]],
  ['requestitems',['requestItems',['../classQXmppDiscoveryManager.html#ac6b173d943634603beeb43c15609efe4',1,'QXmppDiscoveryManager']]],
  ['requestpermissions',['requestPermissions',['../classQXmppMucRoom.html#a8b7cb2b8755a8cd18bf0d98cb3c3a0aa',1,'QXmppMucRoom']]],
  ['requesttime',['requestTime',['../classQXmppEntityTimeManager.html#ab6cb76de7eb717bb8f332b7ed643fb7b',1,'QXmppEntityTimeManager']]],
  ['requestvcard',['requestVCard',['../classQXmppVCardManager.html#a71c114c5375575004bd1e2593aff0ba9',1,'QXmppVCardManager']]],
  ['requestversion',['requestVersion',['../classQXmppVersionManager.html#ae63fec70ad9b12cb585cb2d46b8e1406',1,'QXmppVersionManager']]],
  ['reserveports',['reservePorts',['../classQXmppIceComponent.html#a1fc342ff0fa196320b86a2c1413b33fc',1,'QXmppIceComponent']]],
  ['resource',['resource',['../classQXmppBindIq.html#ac6aa0a84579d18f28196301a774a6e42',1,'QXmppBindIq::resource()'],['../classQXmppConfiguration.html#ad6969bdce483c31e1196ffb0cca800f3',1,'QXmppConfiguration::resource()']]],
  ['responder',['responder',['../classQXmppJingleIq.html#ad77bd95c596dbef85b9d84ff72fb4716',1,'QXmppJingleIq']]],
  ['result',['Result',['../classQXmppDataForm.html#adab12c436b8c450e2b4f59da1aecadeeae5ab980ce478727be2a09112bd55e2f9',1,'QXmppDataForm::Result()'],['../classQXmppIq.html#a6bc7a0505a3be7309051ae2432a3d826a8fa093ce2dcc1baf865ca6203d2712f1',1,'QXmppIq::Result()'],['../classQXmppDialback.html#a0448107c56f892056f359013b80798bcaa6debf8f80d7366af3cff72363fd0477',1,'QXmppDialback::Result()']]],
  ['resultsetquery',['resultSetQuery',['../classQXmppArchiveListIq.html#aed31e99a9387ef300bf91564f83f2e84',1,'QXmppArchiveListIq::resultSetQuery()'],['../classQXmppArchiveRetrieveIq.html#a927c46455efcff2fb9221f9246fcf629',1,'QXmppArchiveRetrieveIq::resultSetQuery()']]],
  ['resultsetreply',['resultSetReply',['../classQXmppArchiveChatIq.html#a63d9405b2b4c4b0573905a2e52a95c96',1,'QXmppArchiveChatIq::resultSetReply()'],['../classQXmppArchiveListIq.html#a47bb290958acb0721b35bb51161fa1da',1,'QXmppArchiveListIq::resultSetReply()']]],
  ['retrievecollection',['retrieveCollection',['../classQXmppArchiveManager.html#a5a8584a4dfb0c2fa8bb0e85690c269f9',1,'QXmppArchiveManager::retrieveCollection(const QString &amp;jid, const QDateTime &amp;start, const QXmppResultSetQuery &amp;rsm=QXmppResultSetQuery())'],['../classQXmppArchiveManager.html#a7967bec8510af778f581d3232193895f',1,'QXmppArchiveManager::retrieveCollection(const QString &amp;jid, const QDateTime &amp;start, int max)']]],
  ['ringing',['ringing',['../classQXmppJingleIq.html#a2cc94c4e2e8dec892d8388aca47b0268',1,'QXmppJingleIq::ringing()'],['../classQXmppCall.html#ac661611e7d0bf5ebcdf56a28d60a95aa',1,'QXmppCall::ringing()']]],
  ['role',['Role',['../classQXmppMucItem.html#a5de278115b806b129dd6944dc8230d4a',1,'QXmppMucItem::Role()'],['../classQXmppMucItem.html#af65444d3b29bbb8d78b4d25aa8f02894',1,'QXmppMucItem::role() const ']]],
  ['roomadded',['roomAdded',['../classQXmppMucManager.html#a948446ebb49b07e772d8a70a0b8e71e6',1,'QXmppMucManager']]],
  ['rooms',['rooms',['../classQXmppMucManager.html#a574bd5b755a4463895f5376977d6a0a7',1,'QXmppMucManager']]],
  ['rostermanager',['rosterManager',['../classQXmppClient.html#a6a0bb409bad66a4f5ea91056ee190ad4',1,'QXmppClient']]],
  ['rosterreceived',['rosterReceived',['../classQXmppRosterManager.html#a978cf900248b0ef144460bb52052ded8',1,'QXmppRosterManager']]]
];

==> qxmpp_0.7.6.orig.tar.gz: qxmpp-0.7.6/doc/html/search/all_72.js <==
var searchData=
[
  ['readframes',['readFrames',['../classQXmppRtpVideoChannel.html#a2d2c5854406f34fedbd10d6096428493',1,'QXmppRtpVideoChannel']]],
  ['reason',['reason',['../classQXmppJingleIq.html#a0109cfd1525f9ee69a40ae0ce3962d69',1,'QXmppJingleIq::reason()'],['../classQXmppJingleIq.html#a9027b28bc5f929ee415f0de50563cac7',1,'QXmppJingleIq::reason() const '],['../classQXmppMucItem.html#a7b5574030b7bb253c23ccf46fffde87e',1,'QXmppMucItem::reason()']]],
  ['receiptid',['receiptId',['../classQXmppMessage.html#a3df33f75c06de9a3fbe3897ca89893db',1,'QXmppMessage']]],
  ['receivedmessage',['ReceivedMessage',['../classQXmppLogger.html#a932dbbd4f70a1e9c0ff8f452e61fc9b8a9fe070da70e5b2a5c2e6e97a58ee8da7',1,'QXmppLogger']]],
  ['refusesubscription',['refuseSubscription',['../classQXmppRosterManager.html#a9e9ffd157b981d1fb4a3b641de2890c7',1,'QXmppRosterManager']]],
  ['region',['region',['../classQXmppVCardAddress.html#a02bd9c333ef0d1d3eac3853bb8391849',1,'QXmppVCardAddress']]],
  ['relayedtype',['RelayedType',['../classQXmppJingleCandidate.html#a6314b3ed7de59b68131db6ffab55fe7daca50a30f0ac47c89e25b5f74b846cffb',1,'QXmppJingleCandidate']]],
  ['remotedomain',['remoteDomain',['../classQXmppOutgoingServer.html#acf167e9cf078b1ee9ef80fd2d3ac0b83',1,'QXmppOutgoingServer']]],
  ['remove',['Remove',['../classQXmppRosterIq_1_1Item.html#a0133cf9262cec7e299c4db7c247c5514a126d552db04eb0336747ca34e2c91cee',1,'QXmppRosterIq::Item']]],
  ['removecollections',['removeCollections',['../classQXmppArchiveManager.html#a3de27735449b3fb10a1e85032ed3e0b6',1,'QXmppArchiveManager']]],
  ['removeextension',['removeExtension',['../classQXmppClient.html#ae48477dc92abd66193789bfc60d16d62',1,'QXmppClient']]],
  ['removeitem',['removeItem',['../classQXmppRosterManager.html#a0ac3bd1ee2cbe8e99c3da55f9423fe20',1,'QXmppRosterManager']]],
  ['renameitem',['renameItem',['../classQXmppRosterManager.html#a65ecf5954b56e1d38be5b3554c4e3f30',1,'QXmppRosterManager']]],
  ['reopen',['reopen',['../classQXmppLogger.html#a18ebf48f34358d20dd57502a9db2f0c0',1,'QXmppLogger']]],
  ['requestclientvcard',['requestClientVCard',['../classQXmppVCardManager.html#a3f049d6356f93f5f8fa81a1c30ea5ba9',1,'QXmppVCardManager']]],
  ['requestconfiguration',['requestConfiguration',['../classQXmppMucRoom.html#ab20d3d15a70354d109d1f30a13c8c1df',1,'QXmppMucRoom']]],
  ['requestinfo',['requestInfo',['../classQXmppDiscoveryManager.html#a81facc7b29132ee7f13c26d8d441e611',1,'QXmppDiscoveryManager']]],
  ['requestitems',['requestItems',['../classQXmppDiscoveryManager.html#ac6b173d943634603beeb43c15609efe4',1,'QXmppDiscoveryManager']]],
  ['requestpermissions',['requestPermissions',['../classQXmppMucRoom.html#a8b7cb2b8755a8cd18bf0d98cb3c3a0aa',1,'QXmppMucRoom']]],
  ['requesttime',['requestTime',['../classQXmppEntityTimeManager.html#ab6cb76de7eb717bb8f332b7ed643fb7b',1,'QXmppEntityTimeManager']]],
  ['requestvcard',['requestVCard',['../classQXmppVCardManager.html#a71c114c5375575004bd1e2593aff0ba9',1,'QXmppVCardManager']]],
  ['requestversion',['requestVersion',['../classQXmppVersionManager.html#ae63fec70ad9b12cb585cb2d46b8e1406',1,'QXmppVersionManager']]],
  ['reserveports',['reservePorts',['../classQXmppIceComponent.html#a1fc342ff0fa196320b86a2c1413b33fc',1,'QXmppIceComponent']]],
  ['resource',['resource',['../classQXmppBindIq.html#ac6aa0a84579d18f28196301a774a6e42',1,'QXmppBindIq::resource()'],['../classQXmppConfiguration.html#ad6969bdce483c31e1196ffb0cca800f3',1,'QXmppConfiguration::resource()']]],
  ['responder',['responder',['../classQXmppJingleIq.html#ad77bd95c596dbef85b9d84ff72fb4716',1,'QXmppJingleIq']]],
  ['result',['Result',['../classQXmppDataForm.html#adab12c436b8c450e2b4f59da1aecadeeae5ab980ce478727be2a09112bd55e2f9',1,'QXmppDataForm::Result()'],['../classQXmppIq.html#a6bc7a0505a3be7309051ae2432a3d826a8fa093ce2dcc1baf865ca6203d2712f1',1,'QXmppIq::Result()'],['../classQXmppDialback.html#a0448107c56f892056f359013b80798bcaa6debf8f80d7366af3cff72363fd0477',1,'QXmppDialback::Result()']]],
  ['resultsetquery',['resultSetQuery',['../classQXmppArchiveListIq.html#aed31e99a9387ef300bf91564f83f2e84',1,'QXmppArchiveListIq::resultSetQuery()'],['../classQXmppArchiveRetrieveIq.html#a927c46455efcff2fb9221f9246fcf629',1,'QXmppArchiveRetrieveIq::resultSetQuery()']]],
  ['resultsetreply',['resultSetReply',['../classQXmppArchiveChatIq.html#a63d9405b2b4c4b0573905a2e52a95c96',1,'QXmppArchiveChatIq::resultSetReply()'],['../classQXmppArchiveListIq.html#a47bb290958acb0721b35bb51161fa1da',1,'QXmppArchiveListIq::resultSetReply()']]],
  ['retrievecollection',['retrieveCollection',['../classQXmppArchiveManager.html#a5a8584a4dfb0c2fa8bb0e85690c269f9',1,'QXmppArchiveManager::retrieveCollection(const QString &amp;jid, const QDateTime &amp;start, const QXmppResultSetQuery &amp;rsm=QXmppResultSetQuery())'],['../classQXmppArchiveManager.html#a7967bec8510af778f581d3232193895f',1,'QXmppArchiveManager::retrieveCollection(const QString &amp;jid, const QDateTime &amp;start, int max)']]],
  ['ringing',['ringing',['../classQXmppJingleIq.html#a2cc94c4e2e8dec892d8388aca47b0268',1,'QXmppJingleIq::ringing()'],['../classQXmppCall.html#ac661611e7d0bf5ebcdf56a28d60a95aa',1,'QXmppCall::ringing()']]],
  ['role',['role',['../classQXmppMucItem.html#af65444d3b29bbb8d78b4d25aa8f02894',1,'QXmppMucItem::role() const '],['../classQXmppMucItem.html#a5de278115b806b129dd6944dc8230d4a',1,'QXmppMucItem::Role()']]],
  ['roomadded',['roomAdded',['../classQXmppMucManager.html#a948446ebb49b07e772d8a70a0b8e71e6',1,'QXmppMucManager']]],
  ['rooms',['rooms',['../classQXmppMucManager.html#a574bd5b755a4463895f5376977d6a0a7',1,'QXmppMucManager']]],
  ['rostermanager',['rosterManager',['../classQXmppClient.html#a6a0bb409bad66a4f5ea91056ee190ad4',1,'QXmppClient']]],
  ['rosterreceived',['rosterReceived',['../classQXmppRosterManager.html#a978cf900248b0ef144460bb52052ded8',1,'QXmppRosterManager']]]
];
